@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2014 Jeffrey Stedfast and Michael Zucchi
+ *  Copyright (C) 2000-2011 Jeffrey Stedfast and Michael Zucchi
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -102,7 +102,7 @@ static unsigned char tohex[16] = {
 
 /**
  * g_mime_content_encoding_from_string:
- * @str: a string representing a Content-Transfer-Encoding value
+ * @str: string representing a Content-Transfer-Encoding value
  *
  * Gets the appropriate #GMimeContentEncoding enumeration value based
  * on the input string.
@@ -117,10 +117,6 @@ g_mime_content_encoding_from_string (const char *str)
 		return GMIME_CONTENT_ENCODING_7BIT;
 	else if (!g_ascii_strcasecmp (str, "8bit"))
 		return GMIME_CONTENT_ENCODING_8BIT;
-	else if (!g_ascii_strcasecmp (str, "7-bit"))
-		return GMIME_CONTENT_ENCODING_7BIT;
-	else if (!g_ascii_strcasecmp (str, "8-bit"))
-		return GMIME_CONTENT_ENCODING_8BIT;
 	else if (!g_ascii_strcasecmp (str, "binary"))
 		return GMIME_CONTENT_ENCODING_BINARY;
 	else if (!g_ascii_strcasecmp (str, "base64"))
@@ -131,8 +127,6 @@ g_mime_content_encoding_from_string (const char *str)
 		return GMIME_CONTENT_ENCODING_UUENCODE;
 	else if (!g_ascii_strcasecmp (str, "x-uuencode"))
 		return GMIME_CONTENT_ENCODING_UUENCODE;
-	else if (!g_ascii_strcasecmp (str, "x-uue"))
-		return GMIME_CONTENT_ENCODING_UUENCODE;
 	else
 		return GMIME_CONTENT_ENCODING_DEFAULT;
 }
@@ -421,7 +415,7 @@ g_mime_encoding_base64_encode_close (const unsigned char *inbuf, size_t inlen, u
 size_t
 g_mime_encoding_base64_encode_step (const unsigned char *inbuf, size_t inlen, unsigned char *outbuf, int *state, guint32 *save)
 {
-	register const unsigned char *inptr;
+	const register unsigned char *inptr;
 	register unsigned char *outptr;
 	
 	if (inlen == 0)
@@ -507,7 +501,7 @@ g_mime_encoding_base64_encode_step (const unsigned char *inbuf, size_t inlen, un
 size_t
 g_mime_encoding_base64_decode_step (const unsigned char *inbuf, size_t inlen, unsigned char *outbuf, int *state, guint32 *save)
 {
-	register const unsigned char *inptr;
+	const register unsigned char *inptr;
 	register unsigned char *outptr;
 	const unsigned char *inend;
 	register guint32 saved;
@@ -670,7 +664,7 @@ size_t
 g_mime_encoding_uuencode_step (const unsigned char *inbuf, size_t inlen, unsigned char *outbuf, unsigned char *uubuf, int *state, guint32 *save)
 {
 	register unsigned char *outptr, *bufptr;
-	register const unsigned char *inptr;
+	const register unsigned char *inptr;
 	const unsigned char *inend;
 	unsigned char b0, b1, b2;
 	guint32 saved;
@@ -784,7 +778,7 @@ g_mime_encoding_uuencode_step (const unsigned char *inbuf, size_t inlen, unsigne
 size_t
 g_mime_encoding_uudecode_step (const unsigned char *inbuf, size_t inlen, unsigned char *outbuf, int *state, guint32 *save)
 {
-	register const unsigned char *inptr;
+	const register unsigned char *inptr;
 	register unsigned char *outptr;
 	const unsigned char *inend;
 	unsigned char ch;
@@ -940,7 +934,7 @@ g_mime_encoding_quoted_encode_close (const unsigned char *inbuf, size_t inlen, u
 size_t
 g_mime_encoding_quoted_encode_step (const unsigned char *inbuf, size_t inlen, unsigned char *outbuf, int *state, guint32 *save)
 {
-	register const unsigned char *inptr = inbuf;
+	const register unsigned char *inptr = inbuf;
 	const unsigned char *inend = inbuf + inlen;
 	register unsigned char *outptr = outbuf;
 	register guint32 sofar = *save;  /* keeps track of how many chars on a line */
