@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2014 Jeffrey Stedfast
+ *  Copyright (C) 2000-2011 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -86,72 +86,52 @@ print_mime_struct (GMimeStream *stream, GMimeObject *part, int depth)
 	}
 }
 
+
+static void
+header_cb (GMimeParser *parser, const char *header, const char *value, gint64 offset, gpointer user_data)
+{
+	GMimeStream *stream = user_data;
+	
+	g_mime_stream_printf (stream, "%lld: %s: %s\n", offset, header, value);
+}
+
 static void
 test_parser (GMimeParser *parser, GMimeStream *mbox, GMimeStream *summary)
 {
-	gint64 message_begin, message_end, headers_begin, headers_end;
-	InternetAddressList *list;
+	gint64 headers_begin, headers_end, start, end;
 	GMimeMessage *message;
-	char *marker, *buf;
-	const char *subject;
-	const char *sender;
-	int tz_offset;
+	const char *exev;
 	int nmsg = 0;
-	time_t date;
+	char *from;
 	
 	while (!g_mime_parser_eos (parser)) {
-		message_begin = g_mime_parser_tell (parser);
+		start = g_mime_parser_tell (parser);
 		if (!(message = g_mime_parser_construct_message (parser)))
 			throw (exception_new ("failed to parse message #%d", nmsg));
 		
-		message_end = g_mime_parser_tell (parser);
+		end = g_mime_parser_tell (parser);
 		
 		headers_begin = g_mime_parser_get_headers_begin (parser);
 		headers_end = g_mime_parser_get_headers_end (parser);
 		
-		g_mime_stream_printf (summary, "message offsets: %" G_GINT64_FORMAT ", %" G_GINT64_FORMAT "\n",
-				      message_begin, message_end);
-		g_mime_stream_printf (summary, "header offsets: %" G_GINT64_FORMAT ", %" G_GINT64_FORMAT "\n",
+		g_mime_stream_printf (summary, "message offsets: %lld, %lld\n", start, end);
+		g_mime_stream_printf (summary, "header offsets: %lld, %lld\n",
 				      headers_begin, headers_end);
 		
-		marker = g_mime_parser_get_from (parser);
-		g_mime_stream_printf (summary, "%s\n", marker);
-		
-		if ((sender = g_mime_message_get_sender (message)) != NULL) {
-			list = internet_address_list_parse_string (sender);
-			buf = internet_address_list_to_string (list, FALSE);
-			g_object_unref (list);
-			
-			g_mime_stream_printf (summary, "From: %s\n", buf);
-			g_free (buf);
-		}
-		
-		if ((list = g_mime_message_get_recipients (message, GMIME_RECIPIENT_TYPE_TO)) != NULL &&
-		    internet_address_list_length (list) > 0) {
-			buf = internet_address_list_to_string (list, FALSE);
-			g_mime_stream_printf (summary, "To: %s\n", buf);
-			g_free (buf);
-		}
-		
-		if (!(subject = g_mime_message_get_subject (message)))
-			subject = "";
-		g_mime_stream_printf (summary, "Subject: %s\n", subject);
-		
-		g_mime_message_get_date (message, &date, &tz_offset);
-		buf = g_mime_utils_header_format_date (date, tz_offset);
-		g_mime_stream_printf (summary, "Date: %s\n", buf);
-		g_free (buf);
-		
+		from = g_mime_parser_get_from (parser);
+		g_mime_stream_printf (summary, "%s\n", from);
+		exev = g_mime_object_get_header ((GMimeObject *) message, "X-Evolution");
+		g_mime_stream_printf (summary, "X-Evolution: %s\n", exev ? exev : "None");
 		print_mime_struct (summary, message->mime_part, 0);
 		g_mime_stream_write (summary, "\n", 1);
 		
 		if (mbox) {
-			g_mime_stream_printf (mbox, "%s%s\n", nmsg > 0 ? "\n" : "", marker);
+			g_mime_stream_printf (mbox, "%s%s\n", nmsg > 0 ? "\n" : "", from);
 			g_mime_object_write_to_stream ((GMimeObject *) message, mbox);
 		}
 		
 		g_object_unref (message);
-		g_free (marker);
+		g_free (from);
 		nmsg++;
 	}
 }
@@ -217,7 +197,7 @@ streams_match (GMimeStream *istream, GMimeStream *ostream)
 		}
 		
 		if (bufptr < bufend) {
-			sprintf (errstr, "Error: content does not match at offset %" G_GINT64_FORMAT "\n",
+			sprintf (errstr, "Error: content does not match at offset %lld\n",
 				 offset + (bufptr - buf));
 			/*fprintf (stderr, "-->'%.*s'<--\nvs\n-->'%.*s'<--\n",
 			  bufend - bufptr, bufptr, bufend - bufptr, dbufptr);*/
@@ -264,7 +244,7 @@ int main (int argc, char **argv)
 	int fd, i;
 	
 #ifdef ENABLE_MBOX_MATCH
-	if (mkdir ("./tmp", 0755) == -1 && errno != EEXIST)
+	if (g_mkdir ("./tmp", 0755) == -1 && errno != EEXIST)
 		return 0;
 #endif
 	
@@ -351,6 +331,7 @@ int main (int argc, char **argv)
 					g_mime_parser_set_respect_content_length (parser, TRUE);
 				
 				pstream = g_mime_stream_mem_new ();
+				g_mime_parser_set_header_regex (parser, "^Subject$", header_cb, pstream);
 				test_parser (parser, mstream, pstream);
 				
 #ifdef ENABLE_MBOX_MATCH
@@ -420,6 +401,7 @@ int main (int argc, char **argv)
 #endif
 		
 		ostream = g_mime_stream_fs_new (dup (1));
+		g_mime_parser_set_header_regex (parser, "^Subject$", header_cb, ostream);
 		
 		testsuite_check ("user-input mbox: `%s'", path);
 		try {
@@ -454,19 +436,7 @@ int main (int argc, char **argv)
  exit:
 	
 #ifdef ENABLE_MBOX_MATCH
-	if ((dir = g_dir_open ("./tmp", 0, NULL))) {
-		p = g_stpcpy (input, "./tmp");
-		*p++ = G_DIR_SEPARATOR;
-		
-		while ((dent = g_dir_read_name (dir))) {
-			strcpy (p, dent);
-			unlink (input);
-		}
-		
-		g_dir_close (dir);
-	}
-	
-	rmdir ("./tmp");
+	g_rmdir ("./tmp");
 #endif
 	
 	testsuite_end ();
