@@ -118,33 +118,38 @@ print_mime_part_info (const char *path, GMimeObject *object)
 static void
 print_mime_struct_iter (GMimeMessage *message)
 {
+	const char *jump_to = "4.2.2.2";
 	GMimePartIter *iter;
 	GMimeObject *part;
 	char *path;
 	
 	iter = g_mime_part_iter_new ((GMimeObject *) message);
-	
-	part = g_mime_part_iter_get_parent (iter);
-	print_mime_part_info ("", part);
-	
-	do {
-		part = g_mime_part_iter_get_current (iter);
-		path = g_mime_part_iter_get_path (iter);
-		print_mime_part_info (path, part);
-		g_free (path);
-	} while (g_mime_part_iter_next (iter));
-
+	if (g_mime_part_iter_is_valid (iter)) {
+		part = g_mime_part_iter_get_parent (iter);
+		print_mime_part_info ("TEXT", part);
+		
+		do {
+			part = g_mime_part_iter_get_current (iter);
+			path = g_mime_part_iter_get_path (iter);
+			print_mime_part_info (path, part);
+			g_free (path);
+		} while (g_mime_part_iter_next (iter));
+		
 #if 0
-	fprintf (stdout, "Jumping to 1.2\n");
-	if (g_mime_part_iter_jump_to (iter, "1.2")) {
-		part = g_mime_part_iter_get_current (iter);
-		path = g_mime_part_iter_get_path (iter);
-		print_mime_part_info (path, part);
-		g_free (path);
-	} else {
-		fprintf (stdout, "Failed to jump to 1.2\n");
-	}
+		fprintf (stdout, "Jumping to %s\n", jump_to);
+		if (g_mime_part_iter_jump_to (iter, jump_to)) {
+			part = g_mime_part_iter_get_current (iter);
+			path = g_mime_part_iter_get_path (iter);
+			print_mime_part_info (path, part);
+			g_free (path);
+		} else {
+			fprintf (stdout, "Failed to jump to %s\n", jump_to);
+		}
 #endif
+	} else {
+		part = g_mime_message_get_mime_part (message);
+		print_mime_part_info ("TEXT", part);
+	}
 	
 	g_mime_part_iter_free (iter);
 }
